<?php
/**
 * Plugin Name: Markdown Converter
 * Description: Automatically converts Markdown to HTML for posts and pages, including those posted via the REST API.
 * Version: 1.0
 * Author: James Marsland
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Include Parsedown library.
$parsedown_path = plugin_dir_path( __FILE__ ) . 'includes/Parsedown.php';
if ( file_exists( $parsedown_path ) ) {
    require_once $parsedown_path;
} else {
    add_action( 'admin_notices', function () {
        echo '<div class="notice notice-error"><p>';
        esc_html_e( 'Markdown Converter Plugin: Parsedown library not found. Please ensure Parsedown.php is placed in the includes/ directory.', 'markdown-converter' );
        echo '</p></div>';
    } );
    return; // Stop execution if Parsedown is missing.
}

/**
 * Converts Markdown to HTML.
 *
 * @param string $content The content to convert.
 * @return string The converted content.
 */
function markdown_converter_convert_markdown_to_html( $content ) {
    if ( class_exists( 'Parsedown' ) ) {
        $parsedown = new Parsedown();
        $content   = $parsedown->text( $content ); // Convert Markdown to HTML.
    }
    return $content;
}

// Hook into the_content filter for frontend rendering.
add_filter( 'the_content', 'markdown_converter_convert_markdown_to_html' );

/**
 * Processes Markdown content when a post is saved.
 *
 * @param int $post_id The post ID.
 */
function markdown_converter_process_markdown_on_save( $post_id ) {
    // Skip autosave, revisions, or invalid requests.
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    if ( wp_is_post_revision( $post_id ) ) {
        return;
    }

    // Check user permissions.
    if ( ! current_user_can( 'edit_post', $post_id ) ) {
        return;
    }

    // Convert Markdown to HTML.
    $post = get_post( $post_id );
    if ( $post && $post->post_content ) {
        $converted_content = markdown_converter_convert_markdown_to_html( $post->post_content );
        remove_action( 'save_post', 'markdown_converter_process_markdown_on_save' ); // Prevent infinite loop.
        wp_update_post(
            array(
                'ID'           => $post_id,
                'post_content' => $converted_content,
            )
        );
        add_action( 'save_post', 'markdown_converter_process_markdown_on_save' );
    }
}
add_action( 'save_post', 'markdown_converter_process_markdown_on_save' );

/**
 * Runs on plugin activation.
 */
function markdown_converter_activate() {
    // Code to execute on plugin activation.
}
register_activation_hook( __FILE__, 'markdown_converter_activate' );

/**
 * Runs on plugin deactivation.
 */
function markdown_converter_deactivate() {
    // Code to execute on plugin deactivation.
}
register_deactivation_hook( __FILE__, 'markdown_converter_deactivate' );
